@@ -5,7 +5,6 @@ Verilog Abstract Syntax Tree Components
 from __future__ import annotations
 
 import itertools
-import logging
 from typing import Optional
 
 from ... import ir
@@ -50,10 +49,8 @@ class Statement(ImplementsToLines):
         To Verilog
         """
         if self.literal:
-            return Lines(
-                self.literal + self.get_inline_comment()[1:]
-            )  # Removes leading space
-        return Lines(self.get_inline_comment()[1:])
+            return Lines(self.literal + self.get_inline_comment())
+        return Lines(self.get_inline_comment()[1:])  # removes leading space
 
     def get_inline_comment(self):
         """
@@ -212,8 +209,6 @@ class Module(ImplementsToLines):
         lines += ");"
         lines.concat(self.local_params, 1)
         for stmt in self.body:
-            if stmt.to_lines() is None:
-                logging.error(type(stmt))
             lines.concat(stmt.to_lines(), 1)
         lines += "endmodule"
         return lines
@@ -307,6 +302,7 @@ class Subsitution(Statement):
         self.lvalue = lvalue
         self.rvalue = rvalue
         self.oper = oper
+
         super().__init__(*args, **kwargs)
 
     def to_lines(self):
@@ -314,9 +310,8 @@ class Subsitution(Statement):
         Converts to Verilog
         """
         assert isinstance(self.oper, str), "Subclasses need to set self.type"
-        itself = f"{self.lvalue} {self.oper} {self.rvalue};"
-        lines = Lines(itself)
-        return lines
+        self.literal = f"{self.lvalue} {self.oper} {self.rvalue};"
+        return super().to_lines()
 
 
 class NonBlockingSubsitution(Subsitution):
@@ -334,7 +329,7 @@ class BlockingSubsitution(Subsitution):
     """
 
     def __init__(self, lvalue: ir.Expression, rvalue: ir.Expression, *args, **kwargs):
-        super().__init__(lvalue, rvalue, "=", *args, *kwargs)
+        super().__init__(lvalue, rvalue, "=", *args, **kwargs)
 
 
 class Declaration(Statement):
